function mh_showGrayGradient_onPanel(msg_input,...
    msg_inputOffset,...
    msg_inputBinsize,...
    msg_interpolationFactor,...
    msg_normalization,...
    msg_displayWidth,...
    msg_traceViewOffset,...
    msg_traceViewScale,...
    msg_yAxisRange,...
    msg_xAxisRange,...
    msg_CLim,...
    msg_axisID,...
    msg_filterSize,...
    msg_showInfo,...
    msg_tag,...
    msg_sourcetag,...
    msg_isolevels,...
    msg_errorLines)

    if nargin <14
        msg_showInfo = 0;
    end
    if nargin<18
        msg_errorLines = [];
    end
    
    msg_inputInterp = interp1([1:size(msg_input,1)]',msg_input,linspace(1,size(msg_input,1)',msg_interpolationFactor*size(msg_input,1)))';
    msg_inputInterp = msg_inputInterp/msg_normalization;
    if ~isempty(msg_errorLines)
        msg_errorLines_interp(:,1) = interp1([1:size(msg_input,1)]',msg_errorLines(:,1),linspace(1,size(msg_input,1)',msg_interpolationFactor*size(msg_input,1)))';
        msg_errorLines_interp(:,1) = msg_errorLines_interp(:,1)/msg_normalization;
        msg_errorLines_interp(:,2) = interp1([1:size(msg_input,1)]',msg_errorLines(:,2),linspace(1,size(msg_input,1)',msg_interpolationFactor*size(msg_input,1)))';
        msg_errorLines_interp(:,2) = msg_errorLines_interp(:,2)/msg_normalization;
    end
    
    if msg_filterSize==-1
        msg_filterSize = round(size(msg_inputInterp,1)/30);
    end
    msg_filterSize = msg_filterSize + mod(msg_filterSize+1,2);
   
    msg_filtered = msg_inputInterp;
    if ~isempty(msg_errorLines)
        msg_errorLines_filtered = msg_errorLines_interp;
    end
    if msg_filterSize>1
        for msg_i=1:size(msg_filtered,1)
            msg_filtered(msg_i) = mean(msg_inputInterp(max(floor(msg_i-msg_filterSize/2),1):min(ceil(msg_i+msg_filterSize/2),size(msg_filtered,1))));
            if ~isempty(msg_errorLines)
                msg_errorLines_filtered(msg_i,1) = mean(msg_errorLines_interp(...
                    max(floor(msg_i-msg_filterSize/2),1):min(ceil(msg_i+msg_filterSize/2),size(msg_filtered,1)),1));
                msg_errorLines_filtered(msg_i,2) = mean(msg_errorLines_interp(...
                    max(floor(msg_i-msg_filterSize/2),1):min(ceil(msg_i+msg_filterSize/2),size(msg_filtered,1)),2));
            end
        end
    end
    
    msg_mx = zeros(size(msg_filtered,1),msg_displayWidth);
    
    for msg_i=1:size(msg_mx,2)
        %msg_mx(:,msg_i) = (1-msg_filtered)*4+0.1;
        msg_mx(:,msg_i) = msg_filtered;
    end

    msg_thisColormap = repmat(linspace(1,0,256)',[1,3]);
    
    msg_scaleend = msg_inputOffset + (size(msg_input,1)-1)*msg_inputBinsize;

   
    axes(msg_axisID);
    image(msg_mx,'CDataMapping','scaled',...
        'YData',linspace(msg_inputOffset,msg_scaleend,size(msg_mx,1)),'XData',linspace(msg_CLim(1),msg_CLim(2),size(msg_mx,2)));
    set(gca,'CLim',msg_CLim);
    colormap(msg_thisColormap);
    hold on

    traceViewOffsetScaled=msg_traceViewOffset;%/msg_traceViewScale;
    % plot uninterpolated
    %plot(msg_traceViewScale*(msg_input+traceViewOffsetScaled),linspace(msg_inputOffset,msg_scaleend,size(msg_input,1))');
    
    % plot interpolated
    plot(msg_filtered,linspace(msg_inputOffset,msg_scaleend,size(msg_filtered,1))','r','LineWidth',2);
    if ~isempty(msg_errorLines)
        plot(msg_errorLines_filtered,linspace(msg_inputOffset,msg_scaleend,size(msg_filtered,1))','k--');
    end        
    ylabel('\mum');
    xlabel('intensity');
    set(gca,'XLim',msg_xAxisRange,'YLim',msg_yAxisRange,'YDir','normal');
    box off
    
    msg_sourcelabelstr='';
    if nargin>15
        if ~isempty(msg_sourcetag)
            msg_sourcelabelstr = sprintf('source file name:\n%s',msg_sourcetag);
        end
    end
    
    if msg_showInfo>0
        axes(msg_showInfo);
        axis([0 1 0 1]);
        text(0,0.7,sprintf('Settings:\n\nName:\n%s\n\n     Amplitude scale factor: %d\n     Interpolation factor: %d\n     Filter size: %d\n\n%s',...        
            msg_tag,msg_normalization,msg_interpolationFactor,msg_filterSize,...
            sprintf('     y axis range: [%d %d]\n     x axis range: [%d %d]\n     c axis range: [%d %d]\n\n     integral: %.0f\n\n%s',...
            msg_yAxisRange(1),msg_yAxisRange(2),msg_xAxisRange(1),msg_xAxisRange(2),msg_CLim(1),msg_CLim(2),sum(msg_input(:)),msg_sourcelabelstr)),...
            'Interpreter','none');
        axis off
    end
    
    if nargin>=17 && ~isempty(msg_isolevels)
        %axes(msg_axisID);
        msg_traceForLevels = [0;msg_filtered;0];
        msg_scaling = linspace(msg_inputOffset,msg_scaleend,size(msg_filtered,1));
        msg_scaldelta = msg_scaling(2)-msg_scaling(1);
        msg_scalOffset = msg_scaling(1);
        for msg_isolevc=1:size(msg_isolevels,2)
            msg_thislev = msg_isolevels(msg_isolevc);

            msg_above = msg_traceForLevels>msg_thislev;
            msg_diff = diff(msg_above);
            msg_crossings_upw = find(msg_diff>0)
            msg_crossings_downw = find(msg_diff<0)
            for kl_crossc=1:size(msg_crossings_upw,1)
                plot([msg_crossings_upw(kl_crossc);msg_crossings_downw(kl_crossc)]*0+msg_thislev,...
                    ([msg_crossings_upw(kl_crossc);msg_crossings_downw(kl_crossc)]-1)*msg_scaldelta+msg_scalOffset,...
                    'k','LineWidth',3);
                hold on
            end
        end
        set(gca,'XLim',msg_xAxisRange,'YLim',msg_yAxisRange,'YDir','normal');
        box off
    end
            
end

